@@ -1,12 +1,13 @@
+import json
 import logging
 import operator
 import os
 import socket
 import uuid
-from abc import ABCMeta, abstractmethod
+from abc import ABC, ABCMeta, abstractmethod
 from enum import Enum
 from functools import reduce, wraps
-from typing import Any, Dict, Iterable, List, NamedTuple, Optional, Type
+from typing import Any, Dict, Iterable, List, NamedTuple, Optional, Tuple, Type, Union
 
 import pandas as pd
 import tenacity as tny
@@ -426,13 +427,12 @@ class ToucanConnector(BaseModel, metaclass=ABCMeta):
         """
         return self.json()
 
-    def _render_datasource(self, data_source: ToucanDataSource) -> dict:
-        data_source_rendered = nosql_apply_parameters_to_query(
-            data_source.dict(), data_source.parameters, handle_errors=True
-        )
-        del data_source_rendered['parameters']
-
-        return data_source_rendered
+    def _get_unique_datasource_identifier(self, data_source: ToucanDataSource) -> dict:
+        # By default we don't know which variable syntax is be supported by the inheriting connector,
+        # so calling `nosql_apply_parameters_to_query` is wrong and will produce the same cache key
+        # for different queries when using custom variable syntax !
+        # Overwrite this method to improve the cache key at places where supported syntaxes are clear.
+        return data_source.dict()
 
     def get_cache_key(
         self,
@@ -457,7 +457,7 @@ class ToucanConnector(BaseModel, metaclass=ABCMeta):
         }
 
         if data_source is not None:
-            unique_identifier['datasource'] = self._render_datasource(data_source)
+            unique_identifier['datasource'] = self._get_unique_datasource_identifier(data_source)
         json_uid = JsonWrapper.dumps(unique_identifier, sort_keys=True, default=hash)
         string_uid = str(uuid.uuid3(uuid.NAMESPACE_OID, json_uid))
         return string_uid
@@ -469,3 +469,35 @@ class ToucanConnector(BaseModel, metaclass=ABCMeta):
 
     def describe(self, data_source: ToucanDataSource):
         """ """
+
+
+TableInfo = Dict[str, Union[str, List[Dict[str, str]]]]
+
+
+class DiscoverableConnector(ABC):
+    @abstractmethod
+    def get_model(self) -> List[TableInfo]:
+        """Tries to get all tables that are available for the connector"""
+
+    def get_model_with_info(self) -> Tuple[List[TableInfo], Dict]:
+        """Tries to get all tables that are available for the connector and gives back some infos about what happenned"""
+        return (self.get_model(), {})
+
+    @staticmethod
+    def format_db_model(
+        unformatted_db_tree: List[Tuple[str, str, str, str, List[Dict[str, str]]]]
+    ) -> List[TableInfo]:
+        if not unformatted_db_tree:
+            return []
+        df = pd.DataFrame(unformatted_db_tree)
+        df.columns = ['database', 'schema', 'type', 'name', 'columns']
+        try:  # if columns is a string
+            df['columns'] = df['columns'].apply(json.loads)
+        except TypeError:  # else ignore
+            pass
+        return (
+            df.groupby(by=['schema', 'database', 'type', 'name'])['columns']
+            .apply(sum)
+            .reset_index()
+            .to_dict('records')
+        )
